@@ -171,7 +171,7 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
         name,
         name_power_net="power",
         name_gas_net="gas",
-        name_heat_net="heat",
+        name_net_heat="heat",
         element_type_power="sgen",
         initial_heat_regulation=1,
         storage_cap=1000,
@@ -209,7 +209,7 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
         self.__load_regulation_multiplier = 1
         self.__heat_regulation_multiplier = initial_heat_regulation
         self.__ambient_temperature_in_k = ambient_temperature
-        self.__name_heat_net = name_heat_net
+        self.name_net_heat = name_net_heat
         self.__heat_exchanger_id = heat_exchanger_id
         self.__storage_builder = (
             EnergyStorage.builder()
@@ -225,7 +225,7 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
         self.power_gen = 0
         self._storage_active = use_storage
 
-        heat_net = multinet[NETS_ACCESS][self.__name_heat_net]
+        heat_net = multinet[NETS_ACCESS][self.name_net_heat]
         power_net = multinet[NETS_ACCESS][self.name_net_power]
         gas_net = multinet[NETS_ACCESS][self.name_net_gas]
 
@@ -277,12 +277,12 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
 
     def get_heat_production(self, multinet):
         try:
-            return multinet[NETS_ACCESS][self.__name_heat_net].heat_exchanger.at[
+            return multinet[NETS_ACCESS][self.name_net_heat].heat_exchanger.at[
                 self.__heat_exchanger_id, "qext_w"
             ]
         except (ValueError, TypeError):
             return (
-                multinet[NETS_ACCESS][self.__name_heat_net]
+                multinet[NETS_ACCESS][self.name_net_heat]
                 .heat_exchanger.loc[self.__heat_exchanger_id, "qext_w"]
                 .values[:]
             )
@@ -329,18 +329,27 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
         return (
             gas_flow
             * self.conversion_factor_kgps_to_mw()
+            * 1000000
             * (0.000028 * self.__ambient_temperature_in_k + 273.3567)
             + 2.1609 * self.__ambient_temperature_in_k
             + 339.714
         )
 
+    @property
+    def heat_efficiency(self):
+        return (
+            (0.000028 * self.__ambient_temperature_in_k + 273.3567)
+            + 2.1609 * self.__ambient_temperature_in_k
+            + 339.714
+        ) * (1 - self.efficiency)
+
     def control_step(self, mn):
         self.time_step(mn, 0)
         self.applied = True
 
     @overrides
     def get_all_net_names(self):
-        return [self.name_net_gas, self.name_net_power, self.__name_heat_net]
+        return [self.name_net_gas, self.name_net_power, self.name_net_heat]
 
     def write_to_net(self, multinet):
         try:
@@ -361,11 +370,11 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
             ] = self.power_gen
 
         try:
-            multinet[NETS_ACCESS][self.__name_heat_net].heat_exchanger.at[
+            multinet[NETS_ACCESS][self.name_net_heat].heat_exchanger.at[
                 self.__heat_exchanger_id, "qext_w"
             ] = -self.heat_energy
         except (ValueError, TypeError):
-            multinet[NETS_ACCESS][self.__name_heat_net].heat_exchanger.loc[
+            multinet[NETS_ACCESS][self.name_net_heat].heat_exchanger.loc[
                 self.__heat_exchanger_id, "qext_w"
             ].values[:] = -self.heat_energy
 
@@ -380,7 +389,7 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
         return {
             self.name_net_power: self._line_power,
             self.name_net_gas: self._pipes_gas,
-            self.__name_heat_net: self._pipes_heat,
+            self.name_net_heat: self._pipes_heat,
         }
 
     @property
@@ -388,7 +397,7 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
         return {
             self.name_net_power: (self.elm_type_power, self.elm_idx_power),
             self.name_net_gas: ("sink", self.elm_idx_gas),
-            self.__name_heat_net: ("heat_exchanger", self.__heat_exchanger_id),
+            self.name_net_heat: ("heat_exchanger", self.__heat_exchanger_id),
         }
 
     @property
@@ -890,7 +899,7 @@ class RegulatedP2HControlMultiEnergy(Controller):
         efficiency,
         name,
         name_power_net="power",
-        name_heat_net="heat",
+        name_net_heat="heat",
         in_service=True,
         order=0,
         level=0,
@@ -911,7 +920,7 @@ class RegulatedP2HControlMultiEnergy(Controller):
 
         self.name = name
         self.__load_regulation_multiplier = 1
-        self.name_net_heat = name_heat_net
+        self.name_net_heat = name_net_heat
         self.name_net_power = name_power_net
         self.__heat_exchanger_id = heat_exchanger_id
         self.heat_energy = 0
@@ -978,8 +987,8 @@ class RegulatedP2HControlMultiEnergy(Controller):
         self.heat_energy = self.calc_heat(self.power_load)
         self.write_to_net(multinet)
 
-    def calc_heat(self, power_in_w):
-        return power_in_w * self.efficiency
+    def calc_heat(self, power_in_mw):
+        return power_in_mw * 1000000 * self.efficiency
 
     def control_step(self, mn):
         self.time_step(mn, 0)
