@@ -237,7 +237,7 @@ def get_bus_junc_res_data(node):
         network = node.network
         if "nets" in node.network:
             network = node.network["nets"][network_name]
-        data_set[network_name] += [network["res_" + cross].iloc[cross_id]]
+        data_set[network_name] += [network["res_" + cross].loc[cross_id]]
     return data_set
 
 
