@@ -182,7 +182,6 @@ def create_small_test_multinet():
     RegulatedP2GControlMultiEnergy(
         mn, p2g_id_el, p2g_id_gas, efficiency=0.8, name="ANp2g"
     )
-
     return mn
 
 
@@ -1427,8 +1426,12 @@ def generate_multi_network_based_on_simbench(
 def create_gas_net_for_power(power_net, gas_deployment_rate, source_sink_ratio=0.05):
     net_gas = ppipes.create_empty_network(name="gas", fluid="lgas")
 
+    bus_index_to_junction_index = {}
     for i in power_net.bus.index:
-        ppipes.create_junction(net_gas, pn_bar=REF_BAR, tfluid_k=REF_TEMP, index=i)
+        junc_id = ppipes.create_junction(
+            net_gas, pn_bar=REF_BAR, tfluid_k=REF_TEMP
+        )
+        bus_index_to_junction_index[i] = junc_id
 
     for i, from_bus, to_bus in zip(
         power_net.trafo.index,
@@ -1437,8 +1440,8 @@ def create_gas_net_for_power(power_net, gas_deployment_rate, source_sink_ratio=0
     ):
         ppipes.create_pipe_from_parameters(
             net_gas,
-            from_junction=from_bus,
-            to_junction=to_bus,
+            from_junction=bus_index_to_junction_index[from_bus],
+            to_junction=bus_index_to_junction_index[to_bus],
             length_km=0.01,
             diameter_m=0.05,
         )
@@ -1451,8 +1454,8 @@ def create_gas_net_for_power(power_net, gas_deployment_rate, source_sink_ratio=0
     ):
         ppipes.create_pipe_from_parameters(
             net_gas,
-            from_junction=from_bus,
-            to_junction=to_bus,
+            from_junction=bus_index_to_junction_index[from_bus],
+            to_junction=bus_index_to_junction_index[to_bus],
             length_km=length * (random.random() / 4 + (7 / 8)),
             diameter_m=0.05,
         )
@@ -1463,11 +1466,13 @@ def create_gas_net_for_power(power_net, gas_deployment_rate, source_sink_ratio=0
         if deployment_c_value < gas_deployment_rate:
             if ratio_c_value > source_sink_ratio:
 
-                ppipes.create_sink(net_gas, junction=i, mdot_kg_per_s=0.1)
+                ppipes.create_sink(
+                    net_gas, junction=bus_index_to_junction_index[i], mdot_kg_per_s=0.1
+                )
             else:
                 ppipes.create_source(
                     net_gas,
-                    junction=i,
+                    junction=bus_index_to_junction_index[i],
                     mdot_kg_per_s=(1 / source_sink_ratio) * 0.1,
                 )
 
@@ -1485,14 +1490,18 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
     net_heat = ppipes.create_empty_network(name="heat", fluid="water")
     start_return_net_id_junctions = max(power_net.bus.index) + 1
 
+    bus_index_to_junction_index = {}
     for i in power_net.bus.index:
-        ppipes.create_junction(net_heat, pn_bar=REF_BAR, tfluid_k=REF_TEMP, index=i)
-        ppipes.create_junction(
-            net_heat,
-            pn_bar=REF_BAR,
-            tfluid_k=REF_TEMP,
-            index=i + start_return_net_id_junctions,
+        junc_index_first = ppipes.create_junction(
+            net_heat, pn_bar=REF_BAR, tfluid_k=REF_TEMP
         )
+        junc_index_second = ppipes.create_junction(
+            net_heat, pn_bar=REF_BAR, tfluid_k=REF_TEMP
+        )
+        bus_index_to_junction_index[i] = junc_index_first
+        bus_index_to_junction_index[
+            i + start_return_net_id_junctions
+        ] = junc_index_second
 
     for i, from_bus, to_bus in zip(
         power_net.trafo.index,
@@ -1501,8 +1510,8 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
     ):
         ppipes.create_pipe_from_parameters(
             net_heat,
-            from_junction=from_bus,
-            to_junction=to_bus,
+            from_junction=bus_index_to_junction_index[from_bus],
+            to_junction=bus_index_to_junction_index[to_bus],
             length_km=0.01,
             diameter_m=0.075,
             k_mm=0.025,
@@ -1511,8 +1520,12 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
         )
         ppipes.create_pipe_from_parameters(
             net_heat,
-            from_junction=from_bus + start_return_net_id_junctions,
-            to_junction=to_bus + start_return_net_id_junctions,
+            from_junction=bus_index_to_junction_index[
+                from_bus + start_return_net_id_junctions
+            ],
+            to_junction=bus_index_to_junction_index[
+                to_bus + start_return_net_id_junctions
+            ],
             length_km=0.01,
             diameter_m=0.075,
             k_mm=0.025,
@@ -1528,8 +1541,8 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
     ):
         ppipes.create_pipe_from_parameters(
             net_heat,
-            from_junction=from_bus,
-            to_junction=to_bus,
+            from_junction=bus_index_to_junction_index[from_bus],
+            to_junction=bus_index_to_junction_index[to_bus],
             length_km=length * (random.random() / 4 + (7 / 8)),
             diameter_m=0.075,
             k_mm=0.025,
@@ -1538,8 +1551,12 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
         )
         ppipes.create_pipe_from_parameters(
             net_heat,
-            from_junction=from_bus + start_return_net_id_junctions,
-            to_junction=to_bus + start_return_net_id_junctions,
+            from_junction=bus_index_to_junction_index[
+                from_bus + start_return_net_id_junctions
+            ],
+            to_junction=bus_index_to_junction_index[
+                to_bus + start_return_net_id_junctions
+            ],
             length_km=length * (random.random() / 4 + (7 / 8)),
             diameter_m=0.075,
             k_mm=0.025,
@@ -1552,8 +1569,10 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
         if deployment_c_value < heat_deployment_rate:
             ppipes.create_heat_exchanger(
                 net_heat,
-                from_junction=i,
-                to_junction=i + start_return_net_id_junctions,
+                from_junction=bus_index_to_junction_index[i],
+                to_junction=bus_index_to_junction_index[
+                    i + start_return_net_id_junctions
+                ],
                 diameter_m=0.075,
                 qext_w=-0.1,
             )
@@ -1569,56 +1588,59 @@ def create_heat_net_for_power(power_net, heat_deployment_rate):
 
 
 def create_p2h_in_combined_generated_network(mn, net_power, net_heat, p2h_density):
-    for i in net_heat.heat_exchanger.index:
-        if random.random() < p2h_density:
-            cross_index = net_heat.heat_exchanger["from_junction"][i]
-            load = net_power.load[net_power.load["bus"] == cross_index]
-            if len(load.index) > 0:
-                RegulatedP2HControlMultiEnergy(
-                    mn,
-                    load.index[0],
-                    i,
-                    0.4 + random.random() * 0.5,
-                    name=f"P2H-{i}",
-                )
+    if "heat_exchanger" in net_heat:
+        for i in net_heat.heat_exchanger.index:
+            if random.random() < p2h_density:
+                cross_index = net_heat.heat_exchanger["from_junction"][i]
+                load = net_power.load[net_power.load["bus"] == cross_index]
+                if len(load.index) > 0:
+                    RegulatedP2HControlMultiEnergy(
+                        mn,
+                        load.index[0],
+                        i,
+                        0.4 + random.random() * 0.5,
+                        name=f"P2H-{i}",
+                    )
 
 
 def create_chp_in_combined_generated_network(
     mn, net_power, net_heat, net_gas, chp_density
 ):
-    for i in net_gas.sink.index:
-        if random.random() < chp_density:
-            cross_index = net_gas.sink["junction"][i]
-            sgen = net_power.sgen[net_power.sgen["bus"] == cross_index]
-            heat_ex = net_heat.heat_exchanger[
-                net_heat.heat_exchanger["from_junction"] == cross_index
-            ]
-            if len(sgen.index) > 0 and len(heat_ex.index) > 0:
-                CHPControlMultiEnergy(
-                    mn,
-                    sgen.index[0],
-                    i,
-                    heat_ex.index[0],
-                    0.7 + random.random() * 0.3,
-                    "CHP-{i}",
-                    ambient_temperature=282.5,
-                    element_type_power="sgen",
-                )
+    if "sink" in net_gas:
+        for i in net_gas.sink.index:
+            if random.random() < chp_density:
+                cross_index = net_gas.sink["junction"][i]
+                sgen = net_power.sgen[net_power.sgen["bus"] == cross_index]
+                heat_ex = net_heat.heat_exchanger[
+                    net_heat.heat_exchanger["from_junction"] == cross_index
+                ]
+                if len(sgen.index) > 0 and len(heat_ex.index) > 0:
+                    CHPControlMultiEnergy(
+                        mn,
+                        sgen.index[0],
+                        i,
+                        heat_ex.index[0],
+                        0.7 + random.random() * 0.3,
+                        "CHP-{i}",
+                        ambient_temperature=282.5,
+                        element_type_power="sgen",
+                    )
 
 
 def create_p2g_in_combined_generated_network(mn, net_power, net_gas, p2g_density):
-    for i in net_gas.source.index:
-        if random.random() < p2g_density:
-            cross_index = net_gas.source["junction"][i]
-            load = net_power.load[net_power.load["bus"] == cross_index]
-            if len(load.index) > 0:
-                RegulatedP2GControlMultiEnergy(
-                    mn,
-                    load.index[0],
-                    i,
-                    efficiency=0.85,
-                    name=f"P2G-{i}",
-                )
+    if "source" in net_gas:
+        for i in net_gas.source.index:
+            if random.random() < p2g_density:
+                cross_index = net_gas.source["junction"][i]
+                load = net_power.load[net_power.load["bus"] == cross_index]
+                if len(load.index) > 0:
+                    RegulatedP2GControlMultiEnergy(
+                        mn,
+                        load.index[0],
+                        i,
+                        efficiency=0.85,
+                        name=f"P2G-{i}",
+                    )
 
 
 def generate_multi_network_based_on_power_net(
